@@ -1,11 +1,14 @@
 coef.selection <- function( object, part="full", ... ) {
-   if( !( part %in% c( "full", "outcome" ) ) ) {
-      stop( "argument 'part' must be either 'full' or 'outcome'" )
+   if( !( part %in% c( "full", "outcome", "est" ) ) ) {
+      stop( "argument 'part' must be either 'full', 'outcome', 'est'" )
    }
-   if("maxLik" %in% class(object))
+   if( part == "full" & !is.null( object$coefAll ) ) {
+      coefValues <- object$coefAll
+   } else if("maxLik" %in% class(object)) {
       coefValues <- NextMethod( "coef", object, ...)
-   else
+   } else {
        coefValues <- object$coefficients
+   }
    if( part == "outcome" ) {
       coefValues <- coefValues[ object$param$index$outcome ]
    } else {
