@@ -26,17 +26,17 @@ invMillsRatio <- function( x, all = FALSE ) {
       if( x@family@blurb[1] != "Bivariate probit model\n"  ) {
          stop( errorMessage )
       }
-      result <- data.frame( no = 1:nrow( x@predictors ),
-         row.names = rownames( x@predictors ) )
+      result <- data.frame( no = 1:nrow( predictvglm(x) ),
+         row.names = rownames( predictvglm(x) ) )
       if( length( x@misc$link ) == 1 ) {
          vglmLink <- x@misc$link
       } else {
          vglmLink <- x@misc$link[ "rho" ]
       }
       if( vglmLink %in% c( "identity", "identitylink" ) ) {
-         rho <- x@predictors[ , 3 ]
-      } else if( vglmLink == "rhobit" ){
-         rho <- rhobit( x@predictors[ , 3 ], inverse = TRUE )
+         rho <- predictvglm(x)[ , 3 ]
+      } else if( vglmLink  %in% c( "rhobit", "rhobitlink" ) ){
+         rho <- rhobit( predictvglm(x)[ , 3 ], inverse = TRUE )
       } else {
          stop( "the bivariate probit (binom2.rho) must be either estimated",
             " with link 'rhobit' or 'identity'/'identitylink'" )
@@ -53,46 +53,46 @@ invMillsRatio <- function( x, all = FALSE ) {
          corrEq <- matrix( c( 1, rho[ i ], rho[ i ], 1 ), ncol = 2 )
          corrUneq <- matrix( c( 1, -rho[ i ], -rho[ i ], 1 ), ncol = 2 )
          if( x@y[ i, "11" ] == 1 | all ) {
-            pmvnormValues11[ i ] <- pmvnorm( upper = x@predictors[ i, 1:2 ],
+            pmvnormValues11[ i ] <- pmvnorm( upper = predictvglm(x)[ i, 1:2 ],
                corr = corrEq )
          }
          if( x@y[ i, "10" ] == 1 | all ) {
-            pmvnormValues10[ i ] <- pmvnorm( upper = c( x@predictors[ i, 1 ],
-               -x@predictors[ i, 2 ] ), corr = corrUneq )
+            pmvnormValues10[ i ] <- pmvnorm( upper = c( predictvglm(x)[ i, 1 ],
+               -predictvglm(x)[ i, 2 ] ), corr = corrUneq )
          }
          if( x@y[ i, "01" ] == 1 | all ) {
-            pmvnormValues01[ i ] <- pmvnorm( upper = c( -x@predictors[ i, 1 ],
-               x@predictors[ i, 2 ] ), corr = corrUneq )
+            pmvnormValues01[ i ] <- pmvnorm( upper = c( -predictvglm(x)[ i, 1 ],
+               predictvglm(x)[ i, 2 ] ), corr = corrUneq )
          }
          if( x@y[ i, "00" ] == 1 | all ) {
-            pmvnormValues00[ i ] <- pmvnorm( upper = -x@predictors[ i, 1:2 ],
+            pmvnormValues00[ i ] <- pmvnorm( upper = -predictvglm(x)[ i, 1:2 ],
                corr = corrEq )
          }
       }
 
-      result$IMR11a <- dnorm( x@predictors[ , 1 ] ) *
-         pnorm( ( x@predictors[ , 2 ] - rho * x@predictors[ , 1 ] ) /
+      result$IMR11a <- dnorm( predictvglm(x)[ , 1 ] ) *
+         pnorm( ( predictvglm(x)[ , 2 ] - rho * predictvglm(x)[ , 1 ] ) /
             ( 1 - rho^2 )^0.5 ) / pmvnormValues11
-      result$IMR11b <- dnorm( x@predictors[ , 2 ] ) *
-         pnorm( ( x@predictors[ , 1 ] - rho * x@predictors[ , 2 ] ) /
+      result$IMR11b <- dnorm( predictvglm(x)[ , 2 ] ) *
+         pnorm( ( predictvglm(x)[ , 1 ] - rho * predictvglm(x)[ , 2 ] ) /
             ( 1 - rho^2 )^0.5 ) / pmvnormValues11
-      result$IMR10a <- dnorm( x@predictors[ , 1 ] ) *
-         pnorm( ( -x@predictors[ , 2 ] + rho * x@predictors[ , 1 ] ) /
+      result$IMR10a <- dnorm( predictvglm(x)[ , 1 ] ) *
+         pnorm( ( -predictvglm(x)[ , 2 ] + rho * predictvglm(x)[ , 1 ] ) /
             ( 1 - rho^2 )^0.5 ) / pmvnormValues10
-      result$IMR10b <- -dnorm( x@predictors[ , 2 ] ) *
-         pnorm( ( x@predictors[ , 1 ] - rho * x@predictors[ , 2 ] ) /
+      result$IMR10b <- -dnorm( predictvglm(x)[ , 2 ] ) *
+         pnorm( ( predictvglm(x)[ , 1 ] - rho * predictvglm(x)[ , 2 ] ) /
             ( 1 - rho^2 )^0.5 ) / pmvnormValues10
-      result$IMR01a <- -dnorm( x@predictors[ , 1 ] ) *
-         pnorm( ( x@predictors[ , 2 ] - rho * x@predictors[ , 1 ] ) /
+      result$IMR01a <- -dnorm( predictvglm(x)[ , 1 ] ) *
+         pnorm( ( predictvglm(x)[ , 2 ] - rho * predictvglm(x)[ , 1 ] ) /
             ( 1 - rho^2 )^0.5 ) / pmvnormValues01
-      result$IMR01b <- dnorm( x@predictors[ , 2 ] ) *
-         pnorm( ( -x@predictors[ , 1 ] + rho * x@predictors[ , 2 ] ) /
+      result$IMR01b <- dnorm( predictvglm(x)[ , 2 ] ) *
+         pnorm( ( -predictvglm(x)[ , 1 ] + rho * predictvglm(x)[ , 2 ] ) /
             ( 1 - rho^2 )^0.5 ) / pmvnormValues01
-      result$IMR00a <- -dnorm( x@predictors[ , 1 ] ) *
-         pnorm( ( -x@predictors[ , 2 ] + rho * x@predictors[ , 1 ] ) /
+      result$IMR00a <- -dnorm( predictvglm(x)[ , 1 ] ) *
+         pnorm( ( -predictvglm(x)[ , 2 ] + rho * predictvglm(x)[ , 1 ] ) /
             ( 1 - rho^2 )^0.5 ) / pmvnormValues00
-      result$IMR00b <- -dnorm( x@predictors[ , 2 ] ) *
-         pnorm( ( -x@predictors[ , 1 ] + rho * x@predictors[ , 2 ] ) /
+      result$IMR00b <- -dnorm( predictvglm(x)[ , 2 ] ) *
+         pnorm( ( -predictvglm(x)[ , 1 ] + rho * predictvglm(x)[ , 2 ] ) /
             ( 1 - rho^2 )^0.5 ) / pmvnormValues00
 
       if( all ) {
@@ -109,36 +109,36 @@ invMillsRatio <- function( x, all = FALSE ) {
 
       # only considering the first probit equation
       result$IMR1X <- NA
-      result$IMR1X[ selection1X ] <- dnorm( x@predictors[ selection1X, 1 ] ) /
-         pnorm( x@predictors[ selection1X, 1 ] )
+      result$IMR1X[ selection1X ] <- dnorm( predictvglm(x)[ selection1X, 1 ] ) /
+         pnorm( predictvglm(x)[ selection1X, 1 ] )
 
       result$delta1X <- NA
       result$delta1X[ selection1X ] <- result$IMR1X[ selection1X ] *
-         ( result$IMR1X[ selection1X ] + x@predictors[ selection1X, 1 ] )
+         ( result$IMR1X[ selection1X ] + predictvglm(x)[ selection1X, 1 ] )
 
       result$IMR0X <- NA
-      result$IMR0X[ selection0X ] <- -dnorm( x@predictors[ selection0X, 1 ] ) /
-         pnorm( -x@predictors[ selection0X, 1 ] )
+      result$IMR0X[ selection0X ] <- -dnorm( predictvglm(x)[ selection0X, 1 ] ) /
+         pnorm( -predictvglm(x)[ selection0X, 1 ] )
       result$delta0X <- NA
       result$delta0X[ selection0X ] <- result$IMR0X[ selection0X ] *
-         (result$IMR0X[ selection0X ] + x@predictors[ selection0X, 1 ] )
+         (result$IMR0X[ selection0X ] + predictvglm(x)[ selection0X, 1 ] )
 
       # only considering the second probit equation
       result$IMRX1 <- NA
-      result$IMRX1[ selectionX1 ] <- dnorm( x@predictors[ selectionX1, 2 ] ) /
-         pnorm( x@predictors[ selectionX1, 2 ] )
+      result$IMRX1[ selectionX1 ] <- dnorm( predictvglm(x)[ selectionX1, 2 ] ) /
+         pnorm( predictvglm(x)[ selectionX1, 2 ] )
 
       result$deltaX1 <- NA
       result$deltaX1[ selectionX1 ] <- result$IMRX1[ selectionX1 ] *
-         ( result$IMRX1[ selectionX1 ] + x@predictors[ selectionX1, 2 ] )
+         ( result$IMRX1[ selectionX1 ] + predictvglm(x)[ selectionX1, 2 ] )
 
       result$IMRX0 <- NA
-      result$IMRX0[ selectionX0 ] <- -dnorm( x@predictors[ selectionX0, 2 ] ) /
-         pnorm( -x@predictors[ selectionX0, 2 ] )
+      result$IMRX0[ selectionX0 ] <- -dnorm( predictvglm(x)[ selectionX0, 2 ] ) /
+         pnorm( -predictvglm(x)[ selectionX0, 2 ] )
 
       result$deltaX0 <- NA
       result$deltaX0[ selectionX0 ] <- result$IMRX0[ selectionX0 ] *
-         ( result$IMRX0[ selectionX0 ] + x@predictors[ selectionX0, 2 ] )
+         ( result$IMRX0[ selectionX0 ] + predictvglm(x)[ selectionX0, 2 ] )
 
    } else {
       stop( errorMessage )
